@@ -83,8 +83,10 @@ static gchar* get_device_name()
 	DBusGConnection *bus = dbus_g_bus_get(DBUS_BUS_SYSTEM, &error);
 	if (!bus) {
 		WARN("Failed to get system bus: %s", error->message);
+		g_error_free(error);
 		return NULL;
 	}
+
 	DBusGProxy* mgr_proxy = dbus_g_proxy_new_for_name(bus,
 		BT_SERVICE, BT_DEF_ADAPTER_PATH, BT_DEF_ADAPTER_IF);
 	DBusGProxy* adp_proxy = NULL;
@@ -252,6 +254,8 @@ PDL_Err PDL_Init(unsigned int flags)
 		return PDL_NOERROR;
 	}
 
+	TRACE("Init: Preenv %s", LIB_VERSION);
+
 	/* Get a proper prgname for glib */
 	exepath = get_exe_path();
 	if (!exepath) {
@@ -432,6 +436,7 @@ PDL_Err PDL_GetCallingPath(char *buffer, int bufferLen)
 
 PDL_Err PDL_GetDeviceName(char *buffer, int bufferLen)
 {
+	CHECK_IMPLICIT_PDL_INIT();
 	PDL_Err err;
 	gchar *name = get_device_name();
 	if (!name) {
@@ -552,7 +557,7 @@ PDL_Err PDL_GetOSVersion(PDL_OSVersion *version)
 	version->majorVersion = 1;
 	version->minorVersion = 4;
 	version->revision = 5;
-	version->versionStr = "Preenv 0.1.4";
+	version->versionStr = "Preenv " LIB_VERSION;
 	return PDL_NOERROR;
 }
 
@@ -619,7 +624,7 @@ err_return:
 
 PDL_bool PDL_IsPlugin()
 {
-	/* No Mojo here */
+	/* No support for hybrid applications. */
 	return PDL_FALSE;
 }
 
